@@ -1,23 +1,37 @@
-#!/bin/bash
-
 # BASH completion script for Drush.
 #
 # Place this in your /etc/bash_completion.d/ directory or source it from your
 # ~/.bash_completion or ~/.bash_profile files.  Alternatively, source
 # examples/example.bashrc instead, as it will automatically find and source
 # this file.
+#
+# If you're using ZSH instead of BASH, add the following to your ~/.zshrc file
+# and source it.
+#
+#   autoload bashcompinit
+#   bashcompinit
+#   source /path/to/your/drush.complete.sh
 
 # Ensure drush is available.
 which drush > /dev/null || alias drush &> /dev/null || return
 
 __drush_ps1() {
-  f="${TMPDIR:-/tmp/}/drush-env/drush-drupal-site-$$"
+  f="${TMPDIR:-/tmp/}/drush-env-${USER}/drush-drupal-site-$$"
   if [ -f $f ]
   then
-    DRUPAL_SITE=$(cat "$f")
+    __DRUPAL_SITE=$(cat "$f")
+  else
+    __DRUPAL_SITE="$DRUPAL_SITE"
   fi
 
-  [[ -n "$DRUPAL_SITE" ]] && printf "${1:- (%s)}" "$DRUPAL_SITE"
+  # Set DRUSH_PS1_SHOWCOLORHINTS to a non-empty value and define a
+  # __drush_ps1_colorize_alias() function for color hints in your Drush PS1
+  # prompt. See example.prompt.sh for an example implementation.
+  if [ -n "${__DRUPAL_SITE-}" ] && [ -n "${DRUSH_PS1_SHOWCOLORHINTS-}" ]; then
+    __drush_ps1_colorize_alias
+  fi
+
+  [[ -n "$__DRUPAL_SITE" ]] && printf "${1:- (%s)}" "$__DRUPAL_SITE"
 }
 
 # Completion function, uses the "drush complete" command to retrieve
@@ -29,8 +43,8 @@ _drush_completion() {
   # The '< /dev/null' is a work around for a bug in php libedit stdin handling.
   # Note that libedit in place of libreadline in some distributions. See:
   # https://bugs.launchpad.net/ubuntu/+source/php5/+bug/322214
-  COMPREPLY=( $(drush --early=includes/complete.inc "${COMP_WORDS[@]}" < /dev/null) )
+  COMPREPLY=( $(drush --early=includes/complete.inc "${COMP_WORDS[@]}" < /dev/null 2> /dev/null) )
 }
 
 # Register our completion function. We include common short aliases for Drush.
-complete -o nospace -F _drush_completion d dr drush drush5 drush6 drush6 drush.php
+complete -o bashdefault -o default -o nospace -F _drush_completion d dr drush drush5 drush6 drush7 drush8 drush.php
